==> vscat-1.0.0.tgz: package/tests/highlighting/sources/json/npm-package/results/output.solarized-dark.ts <==
// Jest Snapshot v1, https://goo.gl/fbAQLP

exports[`sources suite json language npm-package test solarized-dark theme 1`] = `
Object {
  "lines": Array [
    "[48;2;0;43;54m [38;2;133;133;133m 1 │ [39m[38;2;147;161;161m{[39m                                                                         [49m",
    "[48;2;0;43;54m [38;2;133;133;133m 2 │ [39m[38;2;74;81;81m·[39m[38;2;74;81;81m·[39m[38;2;133;153;0m\\"name\\"[39m[38;2;147;161;161m:[39m[38;2;74;81;81m·[39m[38;2;42;161;152m\\"test-package\\"[39m[38;2;147;161;161m,[39m                                                 [49m",
    "[48;2;0;43;54m [38;2;133;133;133m 3 │ [39m[38;2;74;81;81m·[39m[38;2;74;81;81m·[39m[38;2;133;153;0m\\"description\\"[39m[38;2;147;161;161m:[39m[38;2;74;81;81m·[39m[38;2;42;161;152m\\"Some[39m[38;2;74;81;81m·[39m[38;2;42;161;152museful[39m[38;2;74;81;81m·[39m[38;2;42;161;152mpackage[39m[38;2;74;81;81m·[39m[38;2;42;161;152mto[39m[38;2;74;81;81m·[39m[38;2;42;161;152mdo[39m[38;2;74;81;81m·[39m[38;2;42;161;152msome[39m[38;2;74;81;81m·[39m[38;2;42;161;152museful[39m[38;2;74;81;81m·[39m[38;2;42;161;152mstuff[39m[38;2;74;81;81m·[39m[38;2;42;161;152mwith[39m[38;2;74;81;81m·[39m[38;2;42;161;152madvanc[39m[38;2;42;161;152m…[39m[49m",
    "[48;2;0;43;54m [38;2;133;133;133m 4 │ [39m[38;2;74;81;81m·[39m[38;2;74;81;81m·[39m[38;2;133;153;0m\\"version\\"[39m[38;2;147;161;161m:[39m[38;2;74;81;81m·[39m[38;2;42;161;152m\\"1.0.0\\"[39m[38;2;147;161;161m,[39m                                                     [49m",
    "[48;2;0;43;54m [38;2;133;133;133m 5 │ [39m[38;2;74;81;81m·[39m[38;2;74;81;81m·[39m[38;2;133;153;0m\\"private\\"[39m[38;2;147;161;161m:[39m[38;2;74;81;81m·[39m[38;2;181;137;0mtrue[39m[38;2;147;161;161m,[39m                                                        [49m",
    "[48;2;0;43;54m [38;2;133;133;133m 6 │ [39m[38;2;74;81;81m·[39m[38;2;74;81;81m·[39m[38;2;133;153;0m\\"license\\"[39m[38;2;147;161;161m:[39m[38;2;74;81;81m·[39m[38;2;42;161;152m\\"MIT\\"[39m[38;2;147;161;161m,[39m                                                       [49m",
    "[48;2;0;43;54m [38;2;133;133;133m 7 │ [39m[38;2;74;81;81m·[39m[38;2;74;81;81m·[39m[38;2;133;153;0m\\"dependencies\\"[39m[38;2;147;161;161m:[39m[38;2;74;81;81m·[39m[38;2;147;161;161m{[39m                                                       [49m",
    "[48;2;0;43;54m [38;2;133;133;133m 8 │ [39m[38;2;74;81;81m·[39m[38;2;74;81;81m·[39m[38;2;74;81;81m·[39m[38;2;74;81;81m·[39m[38;2;133;153;0m\\"package-1\\"[39m[38;2;147;161;161m:[39m[38;2;74;81;81m·[39m[38;2;42;161;152m\\"1.0.0\\"[39m[38;2;147;161;161m,[39m                                                 [49m",
    "[48;2;0;43;54m [38;2;133;133;133m 9 │ [39m[38;2;74;81;81m·[39m[38;2;74;81;81m·[39m[38;2;74;81;81m·[39m[38;2;74;81;81m·[39m[38;2;133;153;0m\\"package-2\\"[39m[38;2;147;161;161m:[39m[38;2;74;81;81m·[39m[38;2;42;161;152m\\"2.0.0\\"[39m[38;2;147;161;161m,[39m                                                 [49m",
    "[48;2;0;43;54m [38;2;133;133;133m10 │ [39m[38;2;74;81;81m·[39m[38;2;74;81;81m·[39m[38;2;74;81;81m·[39m[38;2;74;81;81m·[39m[38;2;133;153;0m\\"package-3\\"[39m[38;2;147;161;161m:[39m[38;2;74;81;81m·[39m[38;2;42;161;152m\\"3.0.0\\"[39m[38;2;147;161;161m,[39m                                                 [49m",
    "[48;2;0;43;54m [38;2;133;133;133m11 │ [39m[38;2;74;81;81m·[39m[38;2;74;81;81m·[39m[38;2;74;81;81m·[39m[38;2;74;81;81m·[39m[38;2;133;153;0m\\"package-4\\"[39m[38;2;147;161;161m:[39m[38;2;74;81;81m·[39m[38;2;42;161;152m\\"4.0.0\\"[39m[38;2;147;161;161m,[39m                                                 [49m",
    "[48;2;0;43;54m [38;2;133;133;133m12 │ [39m[38;2;74;81;81m·[39m[38;2;74;81;81m·[39m[38;2;74;81;81m·[39m[38;2;74;81;81m·[39m[38;2;133;153;0m\\"package-5\\"[39m[38;2;147;161;161m:[39m[38;2;74;81;81m·[39m[38;2;42;161;152m\\"5.0.0\\"[39m[38;2;147;161;161m,[39m                                                 [49m",
    "[48;2;0;43;54m [38;2;133;133;133m13 │ [39m[38;2;74;81;81m·[39m[38;2;74;81;81m·[39m[38;2;74;81;81m·[39m[38;2;74;81;81m·[39m[38;2;133;153;0m\\"package-6\\"[39m[38;2;147;161;161m:[39m[38;2;74;81;81m·[39m[38;2;42;161;152m\\"6.0.0\\"[39m                                                  [49m",
    "[48;2;0;43;54m [38;2;133;133;133m14 │ [39m[38;2;74;81;81m·[39m[38;2;74;81;81m·[39m[38;2;147;161;161m}[39m                                                                       [49m",
    "[48;2;0;43;54m [38;2;133;133;133m15 │ [39m[38;2;147;161;161m}[39m                                                                         [49m",
    "[48;2;0;43;54m [38;2;133;133;133m16 │ [39m                                                                          [49m",
  ],
  "tokens": Array [
    "
 0 │  0, 1 │ #93A1A1 │ {
───┼───────┼─────────┼──────────────────────────────────────────────────
 1 │  0, 2 │ #93A1A1 │   
 1 │  2, 8 │ #859900 │ \\"name\\"
 1 │  8,10 │ #93A1A1 │ : 
 1 │ 10,24 │ #2AA198 │ \\"test-package\\"
 1 │ 24,25 │ #93A1A1 │ ,
───┼───────┼─────────┼──────────────────────────────────────────────────
 2 │  0, 2 │ #93A1A1 │   
 2 │  2,15 │ #859900 │ \\"description\\"
 2 │ 15,17 │ #93A1A1 │ : 
 2 │ 17,90 │ #2AA198 │ \\"Some useful package to do some useful stuff with advanced capabilities.\\"
 2 │ 90,91 │ #93A1A1 │ ,
───┼───────┼─────────┼──────────────────────────────────────────────────
 3 │  0, 2 │ #93A1A1 │   
 3 │  2,11 │ #859900 │ \\"version\\"
 3 │ 11,13 │ #93A1A1 │ : 
 3 │ 13,20 │ #2AA198 │ \\"1.0.0\\"
 3 │ 20,21 │ #93A1A1 │ ,
───┼───────┼─────────┼──────────────────────────────────────────────────
 4 │  0, 2 │ #93A1A1 │   
 4 │  2,11 │ #859900 │ \\"private\\"
 4 │ 11,13 │ #93A1A1 │ : 
 4 │ 13,17 │ #B58900 │ true
 4 │ 17,18 │ #93A1A1 │ ,
───┼───────┼─────────┼──────────────────────────────────────────────────
 5 │  0, 2 │ #93A1A1 │   
 5 │  2,11 │ #859900 │ \\"license\\"
 5 │ 11,13 │ #93A1A1 │ : 
 5 │ 13,18 │ #2AA198 │ \\"MIT\\"
 5 │ 18,19 │ #93A1A1 │ ,
───┼───────┼─────────┼──────────────────────────────────────────────────
 6 │  0, 2 │ #93A1A1 │   
 6 │  2,16 │ #859900 │ \\"dependencies\\"
 6 │ 16,19 │ #93A1A1 │ : {
───┼───────┼─────────┼──────────────────────────────────────────────────
 7 │  0, 4 │ #93A1A1 │     
 7 │  4,15 │ #859900 │ \\"package-1\\"
 7 │ 15,17 │ #93A1A1 │ : 
 7 │ 17,24 │ #2AA198 │ \\"1.0.0\\"
 7 │ 24,25 │ #93A1A1 │ ,
───┼───────┼─────────┼──────────────────────────────────────────────────
 8 │  0, 4 │ #93A1A1 │     
 8 │  4,15 │ #859900 │ \\"package-2\\"
 8 │ 15,17 │ #93A1A1 │ : 
 8 │ 17,24 │ #2AA198 │ \\"2.0.0\\"
 8 │ 24,25 │ #93A1A1 │ ,
───┼───────┼─────────┼──────────────────────────────────────────────────
 9 │  0, 4 │ #93A1A1 │     
 9 │  4,15 │ #859900 │ \\"package-3\\"
 9 │ 15,17 │ #93A1A1 │ : 
 9 │ 17,24 │ #2AA198 │ \\"3.0.0\\"
 9 │ 24,25 │ #93A1A1 │ ,
───┼───────┼─────────┼──────────────────────────────────────────────────
10 │  0, 4 │ #93A1A1 │     
10 │  4,15 │ #859900 │ \\"package-4\\"
10 │ 15,17 │ #93A1A1 │ : 
10 │ 17,24 │ #2AA198 │ \\"4.0.0\\"
10 │ 24,25 │ #93A1A1 │ ,
───┼───────┼─────────┼──────────────────────────────────────────────────
11 │  0, 4 │ #93A1A1 │     
11 │  4,15 │ #859900 │ \\"package-5\\"
11 │ 15,17 │ #93A1A1 │ : 
11 │ 17,24 │ #2AA198 │ \\"5.0.0\\"
11 │ 24,25 │ #93A1A1 │ ,
───┼───────┼─────────┼──────────────────────────────────────────────────
12 │  0, 4 │ #93A1A1 │     
12 │  4,15 │ #859900 │ \\"package-6\\"
12 │ 15,17 │ #93A1A1 │ : 
12 │ 17,24 │ #2AA198 │ \\"6.0.0\\"
───┼───────┼─────────┼──────────────────────────────────────────────────
13 │  0, 3 │ #93A1A1 │   }
───┼───────┼─────────┼──────────────────────────────────────────────────
14 │  0, 1 │ #93A1A1 │ }
───┼───────┼─────────┼──────────────────────────────────────────────────
15 │ none  │         │
",
  ],
}
`;

==> vscat-1.0.1.tgz: package/tests/highlighting/sources/json/npm-package/results/output.solarized-dark.ts <==
// Jest Snapshot v1, https://goo.gl/fbAQLP

exports[`sources suite json language npm-package test solarized-dark theme 1`] = `
Object {
  "lines": Array [
    "[48;2;0;43;54m [38;2;133;133;133m 1 │ [39m[38;2;147;161;161m{[39m                                                                         [49m",
    "[48;2;0;43;54m [38;2;133;133;133m 2 │ [39m[38;2;74;81;81m·[39m[38;2;74;81;81m·[39m[38;2;133;153;0m\\"name\\"[39m[38;2;147;161;161m:[39m[38;2;74;81;81m·[39m[38;2;42;161;152m\\"test-package\\"[39m[38;2;147;161;161m,[39m                                                 [49m",
    "[48;2;0;43;54m [38;2;133;133;133m 3 │ [39m[38;2;74;81;81m·[39m[38;2;74;81;81m·[39m[38;2;133;153;0m\\"description\\"[39m[38;2;147;161;161m:[39m[38;2;74;81;81m·[39m[38;2;42;161;152m\\"Some[39m[38;2;74;81;81m·[39m[38;2;42;161;152museful[39m[38;2;74;81;81m·[39m[38;2;42;161;152mpackage[39m[38;2;74;81;81m·[39m[38;2;42;161;152mto[39m[38;2;74;81;81m·[39m[38;2;42;161;152mdo[39m[38;2;74;81;81m·[39m[38;2;42;161;152msome[39m[38;2;74;81;81m·[39m[38;2;42;161;152museful[39m[38;2;74;81;81m·[39m[38;2;42;161;152mstuff[39m[38;2;74;81;81m·[39m[38;2;42;161;152mwith[39m[38;2;74;81;81m·[39m[38;2;42;161;152madvanc…[39m[49m",
    "[48;2;0;43;54m [38;2;133;133;133m 4 │ [39m[38;2;74;81;81m·[39m[38;2;74;81;81m·[39m[38;2;133;153;0m\\"version\\"[39m[38;2;147;161;161m:[39m[38;2;74;81;81m·[39m[38;2;42;161;152m\\"1.0.0\\"[39m[38;2;147;161;161m,[39m                                                     [49m",
    "[48;2;0;43;54m [38;2;133;133;133m 5 │ [39m[38;2;74;81;81m·[39m[38;2;74;81;81m·[39m[38;2;133;153;0m\\"private\\"[39m[38;2;147;161;161m:[39m[38;2;74;81;81m·[39m[38;2;181;137;0mtrue[39m[38;2;147;161;161m,[39m                                                        [49m",
    "[48;2;0;43;54m [38;2;133;133;133m 6 │ [39m[38;2;74;81;81m·[39m[38;2;74;81;81m·[39m[38;2;133;153;0m\\"license\\"[39m[38;2;147;161;161m:[39m[38;2;74;81;81m·[39m[38;2;42;161;152m\\"MIT\\"[39m[38;2;147;161;161m,[39m                                                       [49m",
    "[48;2;0;43;54m [38;2;133;133;133m 7 │ [39m[38;2;74;81;81m·[39m[38;2;74;81;81m·[39m[38;2;133;153;0m\\"dependencies\\"[39m[38;2;147;161;161m:[39m[38;2;74;81;81m·[39m[38;2;147;161;161m{[39m                                                       [49m",
    "[48;2;0;43;54m [38;2;133;133;133m 8 │ [39m[38;2;74;81;81m·[39m[38;2;74;81;81m·[39m[38;2;74;81;81m·[39m[38;2;74;81;81m·[39m[38;2;133;153;0m\\"package-1\\"[39m[38;2;147;161;161m:[39m[38;2;74;81;81m·[39m[38;2;42;161;152m\\"1.0.0\\"[39m[38;2;147;161;161m,[39m                                                 [49m",
    "[48;2;0;43;54m [38;2;133;133;133m 9 │ [39m[38;2;74;81;81m·[39m[38;2;74;81;81m·[39m[38;2;74;81;81m·[39m[38;2;74;81;81m·[39m[38;2;133;153;0m\\"package-2\\"[39m[38;2;147;161;161m:[39m[38;2;74;81;81m·[39m[38;2;42;161;152m\\"2.0.0\\"[39m[38;2;147;161;161m,[39m                                                 [49m",
    "[48;2;0;43;54m [38;2;133;133;133m10 │ [39m[38;2;74;81;81m·[39m[38;2;74;81;81m·[39m[38;2;74;81;81m·[39m[38;2;74;81;81m·[39m[38;2;133;153;0m\\"package-3\\"[39m[38;2;147;161;161m:[39m[38;2;74;81;81m·[39m[38;2;42;161;152m\\"3.0.0\\"[39m[38;2;147;161;161m,[39m                                                 [49m",
    "[48;2;0;43;54m [38;2;133;133;133m11 │ [39m[38;2;74;81;81m·[39m[38;2;74;81;81m·[39m[38;2;74;81;81m·[39m[38;2;74;81;81m·[39m[38;2;133;153;0m\\"package-4\\"[39m[38;2;147;161;161m:[39m[38;2;74;81;81m·[39m[38;2;42;161;152m\\"4.0.0\\"[39m[38;2;147;161;161m,[39m                                                 [49m",
    "[48;2;0;43;54m [38;2;133;133;133m12 │ [39m[38;2;74;81;81m·[39m[38;2;74;81;81m·[39m[38;2;74;81;81m·[39m[38;2;74;81;81m·[39m[38;2;133;153;0m\\"package-5\\"[39m[38;2;147;161;161m:[39m[38;2;74;81;81m·[39m[38;2;42;161;152m\\"5.0.0\\"[39m[38;2;147;161;161m,[39m                                                 [49m",
    "[48;2;0;43;54m [38;2;133;133;133m13 │ [39m[38;2;74;81;81m·[39m[38;2;74;81;81m·[39m[38;2;74;81;81m·[39m[38;2;74;81;81m·[39m[38;2;133;153;0m\\"package-6\\"[39m[38;2;147;161;161m:[39m[38;2;74;81;81m·[39m[38;2;42;161;152m\\"6.0.0\\"[39m                                                  [49m",
    "[48;2;0;43;54m [38;2;133;133;133m14 │ [39m[38;2;74;81;81m·[39m[38;2;74;81;81m·[39m[38;2;147;161;161m}[39m                                                                       [49m",
    "[48;2;0;43;54m [38;2;133;133;133m15 │ [39m[38;2;147;161;161m}[39m                                                                         [49m",
    "[48;2;0;43;54m [38;2;133;133;133m16 │ [39m                                                                          [49m",
  ],
  "tokens": Array [
    "
 0 │  0, 1 │ #93A1A1 │ {
───┼───────┼─────────┼──────────────────────────────────────────────────
 1 │  0, 2 │ #93A1A1 │   
 1 │  2, 8 │ #859900 │ \\"name\\"
 1 │  8,10 │ #93A1A1 │ : 
 1 │ 10,24 │ #2AA198 │ \\"test-package\\"
 1 │ 24,25 │ #93A1A1 │ ,
───┼───────┼─────────┼──────────────────────────────────────────────────
 2 │  0, 2 │ #93A1A1 │   
 2 │  2,15 │ #859900 │ \\"description\\"
 2 │ 15,17 │ #93A1A1 │ : 
 2 │ 17,90 │ #2AA198 │ \\"Some useful package to do some useful stuff with advanced capabilities.\\"
 2 │ 90,91 │ #93A1A1 │ ,
───┼───────┼─────────┼──────────────────────────────────────────────────
 3 │  0, 2 │ #93A1A1 │   
 3 │  2,11 │ #859900 │ \\"version\\"
 3 │ 11,13 │ #93A1A1 │ : 
 3 │ 13,20 │ #2AA198 │ \\"1.0.0\\"
 3 │ 20,21 │ #93A1A1 │ ,
───┼───────┼─────────┼──────────────────────────────────────────────────
 4 │  0, 2 │ #93A1A1 │   
 4 │  2,11 │ #859900 │ \\"private\\"
 4 │ 11,13 │ #93A1A1 │ : 
 4 │ 13,17 │ #B58900 │ true
 4 │ 17,18 │ #93A1A1 │ ,
───┼───────┼─────────┼──────────────────────────────────────────────────
 5 │  0, 2 │ #93A1A1 │   
 5 │  2,11 │ #859900 │ \\"license\\"
 5 │ 11,13 │ #93A1A1 │ : 
 5 │ 13,18 │ #2AA198 │ \\"MIT\\"
 5 │ 18,19 │ #93A1A1 │ ,
───┼───────┼─────────┼──────────────────────────────────────────────────
 6 │  0, 2 │ #93A1A1 │   
 6 │  2,16 │ #859900 │ \\"dependencies\\"
 6 │ 16,19 │ #93A1A1 │ : {
───┼───────┼─────────┼──────────────────────────────────────────────────
 7 │  0, 4 │ #93A1A1 │     
 7 │  4,15 │ #859900 │ \\"package-1\\"
 7 │ 15,17 │ #93A1A1 │ : 
 7 │ 17,24 │ #2AA198 │ \\"1.0.0\\"
 7 │ 24,25 │ #93A1A1 │ ,
───┼───────┼─────────┼──────────────────────────────────────────────────
 8 │  0, 4 │ #93A1A1 │     
 8 │  4,15 │ #859900 │ \\"package-2\\"
 8 │ 15,17 │ #93A1A1 │ : 
 8 │ 17,24 │ #2AA198 │ \\"2.0.0\\"
 8 │ 24,25 │ #93A1A1 │ ,
───┼───────┼─────────┼──────────────────────────────────────────────────
 9 │  0, 4 │ #93A1A1 │     
 9 │  4,15 │ #859900 │ \\"package-3\\"
 9 │ 15,17 │ #93A1A1 │ : 
 9 │ 17,24 │ #2AA198 │ \\"3.0.0\\"
 9 │ 24,25 │ #93A1A1 │ ,
───┼───────┼─────────┼──────────────────────────────────────────────────
10 │  0, 4 │ #93A1A1 │     
10 │  4,15 │ #859900 │ \\"package-4\\"
10 │ 15,17 │ #93A1A1 │ : 
10 │ 17,24 │ #2AA198 │ \\"4.0.0\\"
10 │ 24,25 │ #93A1A1 │ ,
───┼───────┼─────────┼──────────────────────────────────────────────────
11 │  0, 4 │ #93A1A1 │     
11 │  4,15 │ #859900 │ \\"package-5\\"
11 │ 15,17 │ #93A1A1 │ : 
11 │ 17,24 │ #2AA198 │ \\"5.0.0\\"
11 │ 24,25 │ #93A1A1 │ ,
───┼───────┼─────────┼──────────────────────────────────────────────────
12 │  0, 4 │ #93A1A1 │     
12 │  4,15 │ #859900 │ \\"package-6\\"
12 │ 15,17 │ #93A1A1 │ : 
12 │ 17,24 │ #2AA198 │ \\"6.0.0\\"
───┼───────┼─────────┼──────────────────────────────────────────────────
13 │  0, 3 │ #93A1A1 │   }
───┼───────┼─────────┼──────────────────────────────────────────────────
14 │  0, 1 │ #93A1A1 │ }
───┼───────┼─────────┼──────────────────────────────────────────────────
15 │ none  │         │
",
  ],
}
`;
